Bloom Filter Trie: BFT_annotation Struct Reference

Bloom Filter Trie

- Main Page
- Data Structures
- Files

- Data Structures
- Data Structure Index
- Data Fields

Data Fields
BFT_annotation Struct Reference

Annotation associated with a BFT_kmer. More...

## Data Fields
uint8_t * | annot
uint8_t * | annot_ext
uint8_t * | annot_cplx
int | size_annot
int | size_annot_cplx
uint8_t | from_BFT

## Detailed Description

Annotation associated with a BFT_kmer.

A BFT_annotation contains the set of colors associated with a k-mer of a BFT_Root.

The documentation for this struct was generated from the following file:

- include/bft.h